# ADVCALC
## How to use it
##### First use, `pip instal advcalc`.
##### Then, import it in your python file by using `import ADVCALC` or you can use `from ADVCALC import pow` or what so ever.

##### The functions include `advcalc``add``sub``div``mul``sqrt``square``round_without_decimal_place``round_with_decimal_place``cube``cbrt``and``pow`